{
    "$graph": [
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#main/bait_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference_genome"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#main/target_intervals"
                }
            ],
            "steps": [
                {
                    "run": "#picard-BedToIntervalList.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 4000,
                            "outdirMin": 12000,
                            "tmpdirMin": 12000
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/bait_intervals",
                            "id": "#main/make_bait_interval_list/input_file"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/make_bait_interval_list/reference_sequence"
                        }
                    ],
                    "out": [
                        "#main/make_bait_interval_list/output_interval_list_file"
                    ],
                    "id": "#main/make_bait_interval_list"
                },
                {
                    "run": "#picard-BedToIntervalList.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 4000,
                            "outdirMin": 12000,
                            "tmpdirMin": 12000
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/make_target_interval_list/input_file"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/make_target_interval_list/reference_sequence"
                        }
                    ],
                    "out": [
                        "#main/make_target_interval_list/output_interval_list_file"
                    ],
                    "id": "#main/make_target_interval_list"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/make_bait_interval_list/output_interval_list_file",
                    "id": "#main/bait_interval_list"
                },
                {
                    "type": "File",
                    "outputSource": "#main/make_target_interval_list/output_interval_list_file",
                    "id": "#main/target_interval_list"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/picard:2.10.7"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "2.10.7"
                            ],
                            "package": "picard",
                            "https://schema.org/citation": "http://broadinstitute.github.io/picard"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "doc": "The bed file to be converted to interval_list format.  Required.",
                    "inputBinding": {
                        "prefix": "I=",
                        "shellQuote": false
                    },
                    "id": "#picard-BedToIntervalList.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Interval list output filename.",
                    "default": "list.interval_list",
                    "inputBinding": {
                        "prefix": "O=",
                        "shellQuote": false
                    },
                    "id": "#picard-BedToIntervalList.cwl/output_filename"
                },
                {
                    "type": "File",
                    "doc": "The reference sequences in fasta format.",
                    "inputBinding": {
                        "prefix": "SD=",
                        "shellQuote": false
                    },
                    "id": "#picard-BedToIntervalList.cwl/reference_sequence"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#picard-BedToIntervalList.cwl/output_interval_list_file"
                }
            ],
            "baseCommand": [
                "java",
                "-Xmx4g"
            ],
            "arguments": [
                {
                    "valueFrom": "/opt/picard/picard.jar",
                    "position": -1,
                    "prefix": "-jar"
                },
                {
                    "valueFrom": "BedToIntervalList",
                    "position": 0
                }
            ],
            "id": "#picard-BedToIntervalList.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html"
    ]
}
